@@ -9,18 +9,18 @@ use DBI;
 use Exporter;
 use Scalar::Util qw/reftype/;
 use Sub::Name;
-use DBIx::Squirrel::dr          ();
-use DBIx::Squirrel::db          ();
-use DBIx::Squirrel::st          ();
-use DBIx::Squirrel::Iterator    ();
-use DBIx::Squirrel::ResultSet   ();
-use DBIx::Squirrel::ResultClass ();
-use DBIx::Squirrel::Utils       qw/throw/;
+use DBIx::Squirrel::dr   ();
+use DBIx::Squirrel::db   ();
+use DBIx::Squirrel::st   ();
+use DBIx::Squirrel::it   ();
+use DBIx::Squirrel::rs   ();
+use DBIx::Squirrel::rc   ();
+use DBIx::Squirrel::util qw/confessf/;
 use namespace::clean;
 
 BEGIN {
     @DBIx::Squirrel::ISA            = qw/DBI/;
-    $DBIx::Squirrel::VERSION        = "1.005_003";
+    $DBIx::Squirrel::VERSION        = "1.006_000";
     $DBIx::Squirrel::VERSION        = eval($DBIx::Squirrel::VERSION);        ## no critic
     @DBIx::Squirrel::EXPORT_OK      = @DBI::EXPORT_OK;
     %DBIx::Squirrel::EXPORT_TAGS    = %DBI::EXPORT_TAGS;
@@ -33,10 +33,9 @@ BEGIN {
     *DBIx::Squirrel::connect_cached = *DBIx::Squirrel::dr::connect_cached;
     *DBIx::Squirrel::FINISH_ACTIVE_BEFORE_EXECUTE
         = *DBIx::Squirrel::st::FINISH_ACTIVE_BEFORE_EXECUTE;
-    *DBIx::Squirrel::DEFAULT_SLICE = *DBIx::Squirrel::Iterator::DEFAULT_SLICE;
-    *DBIx::Squirrel::DEFAULT_CACHE_SIZE
-        = *DBIx::Squirrel::Iterator::DEFAULT_CACHE_SIZE;
-    *DBIx::Squirrel::CACHE_SIZE_LIMIT = *DBIx::Squirrel::Iterator::CACHE_SIZE_LIMIT;
+    *DBIx::Squirrel::DEFAULT_SLICE      = *DBIx::Squirrel::it::DEFAULT_SLICE;
+    *DBIx::Squirrel::DEFAULT_CACHE_SIZE = *DBIx::Squirrel::it::DEFAULT_CACHE_SIZE;
+    *DBIx::Squirrel::CACHE_SIZE_LIMIT   = *DBIx::Squirrel::it::CACHE_SIZE_LIMIT;
 }
 
 use constant E_BAD_ENT_BIND     => 'Cannot associate with an invalid object';
@@ -46,14 +45,14 @@ use constant E_EXP_HASH_ARR_REF => 'Expected a reference to a HASH or ARRAY';
 # 1. a list of helper function names;
 # 2. a list of names to be imported from the DBI.
 sub _partition_imports_into_helpers_and_dbi_imports {
-    my(@helpers, @dbi);
+    my( @helpers, @dbi );
     while (@_) {
-        next unless defined($_[0]);
-        if ($_[0] =~ m/^database_entit(?:y|ies)$/i) {
+        next unless defined( $_[0] );
+        if ( $_[0] =~ m/^database_entit(?:y|ies)$/i ) {
             shift;
-            if (ref($_[0])) {
-                if (UNIVERSAL::isa($_[0], 'ARRAY')) {
-                    push @helpers, @{+shift};
+            if ( ref( $_[0] ) ) {
+                if ( UNIVERSAL::isa( $_[0], 'ARRAY' ) ) {
+                    push @helpers, @{ +shift };
                 }
                 else {
                     shift;
@@ -67,52 +66,51 @@ sub _partition_imports_into_helpers_and_dbi_imports {
             push @dbi, shift();
         }
     }
-    return (\@helpers, \@dbi);
+    return ( \@helpers, \@dbi );
 }
 
 sub import {
     no strict 'refs';    ## no critic
     my $class  = shift;
     my $caller = caller;
-    my($helpers, $dbi) = _partition_imports_into_helpers_and_dbi_imports(@_);
-    for my $name (@{$helpers}) {
+    my( $helpers, $dbi ) = _partition_imports_into_helpers_and_dbi_imports(@_);
+    for my $name ( @{$helpers} ) {
         my $symbol = $class . '::' . $name;
         my $helper = sub {
-            unless (defined(${$symbol})) {
-                if (@_) {
-                    throw E_BAD_ENT_BIND
-                        unless UNIVERSAL::isa($_[0], 'DBI::db')
-                        or UNIVERSAL::isa($_[0], 'DBI::st')
-                        or UNIVERSAL::isa($_[0], 'DBIx::Squirrel::Iterator');
+            if (@_) {
+                if (   UNIVERSAL::isa( $_[0], 'DBI::db' )
+                    or UNIVERSAL::isa( $_[0], 'DBI::st' )
+                    or UNIVERSAL::isa( $_[0], 'DBIx::Squirrel::it' ) )
+                {
                     ${$symbol} = shift;
                     return ${$symbol};
                 }
             }
-            return unless defined(${$symbol});
+            return unless defined( ${$symbol} );
             if (@_) {
                 my @params = do {
-                    if (@_ == 1 && ref $_[0]) {
-                        if (reftype($_[0]) eq 'ARRAY') {
-                            @{+shift};
+                    if ( @_ == 1 && ref $_[0] ) {
+                        if ( reftype( $_[0] ) eq 'ARRAY' ) {
+                            @{ +shift };
                         }
-                        elsif (reftype($_[0]) eq 'HASH') {
-                            %{+shift};
+                        elsif ( reftype( $_[0] ) eq 'HASH' ) {
+                            %{ +shift };
                         }
                         else {
-                            throw E_EXP_HASH_ARR_REF;
+                            confessf E_EXP_HASH_ARR_REF;
                         }
                     }
                     else {
                         @_;
                     }
                 };
-                if (UNIVERSAL::isa(${$symbol}, 'DBI::db')) {
+                if ( UNIVERSAL::isa( ${$symbol}, 'DBI::db' ) ) {
                     return ${$symbol}->prepare(@params);
                 }
-                elsif (UNIVERSAL::isa(${$symbol}, 'DBI::st')) {
+                elsif ( UNIVERSAL::isa( ${$symbol}, 'DBI::st' ) ) {
                     return ${$symbol}->execute(@params);
                 }
-                elsif (UNIVERSAL::isa(${$symbol}, 'DBIx::Squirrel::Iterator')) {
+                elsif ( UNIVERSAL::isa( ${$symbol}, 'DBIx::Squirrel::it' ) ) {
                     return ${$symbol}->iterate(@params);
                 }
                 else {
@@ -121,13 +119,13 @@ sub import {
             }
             return ${$symbol};
         };
-        *{$symbol} = subname($name => $helper);
-        *{$caller . '::' . $name} = subname($caller . '::' . $name => \&{$symbol})
-            unless defined(&{$caller . '::' . $name});
+        *{$symbol} = subname( $name => $helper );
+        *{ $caller . '::' . $name } = subname( $caller . '::' . $name => \&{$symbol} )
+            unless defined( &{ $caller . '::' . $name } );
     }
-    if (@{$dbi}) {
-        DBI->import(@{$dbi});
-        @_ = ('DBIx::Squirrel', @{$dbi});
+    if ( @{$dbi} ) {
+        DBI->import( @{$dbi} );
+        @_ = ( 'DBIx::Squirrel', @{$dbi} );
         goto &Exporter::import;
     }
     return $class;
